@@ -23,6 +23,7 @@
 #' @param showpm Logical, show normal distributed continuous variables as Mean ± SD. Default: T
 #' @param addOverall (optional, only used if strata are supplied) Adds an overall column to the table. Smd and p-value calculations are performed using only the stratifed clolumns. Default: F
 #' @param pairwise (optional, only used if strata are supplied) When there are three or more strata, it displays the p-values for pairwise comparisons. Default: F
+#' @param pairwise.showtest (optional, only used if strata are supplied) When using pairwise comparison, it displays the test used to calculate p-values for pairwise comparisons. Default: F
 #' @return A matrix object containing what you see is also invisibly returned. This can be assinged a name and exported via write.csv.
 #' @details DETAILS
 #' @examples
@@ -48,7 +49,7 @@
 svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, test = T,
                                showAllLevels = T, printToggle = F, quote = F, smd = F, nonnormal = NULL,
                                catDigits = 1, contDigits = 2, pDigits = 3, Labels = F, labeldata = NULL, minMax = F, showpm = T,
-                               addOverall = F, pairwise = F) {
+                               addOverall = F, pairwise = F, pairwise.showtest = F) {
   setkey <- variable <- level <- . <- val_label <- NULL
 
   if (length(strata) != 1) {
@@ -112,9 +113,9 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
   # cap.tb1 = paste("Table 1: Stratified by ", strata, sep="")
 
   if (Labels & !is.null(labeldata)) {
-    colname.group_var <- unlist(labeldata[get("variable") == strata, "val_label"])
-    if (is.na(colname.group_var[1]) & addOverall) {
-      colname.group_var[1] <- "Overall"
+    colname.group_var <- unlist(labeldata[get("variable") == strata & get("level") %in% unique(data$variables[[strata]]), "val_label"])
+    if (length(colname.group_var) == 0 & addOverall) {
+      colname.group_var <- c("Overall")
     }
     if (showAllLevels == T) {
       # colname.group_var <- unlist(labeldata[get("variable") == strata, "val_label"])
@@ -125,82 +126,104 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
   }
 
   if (pairwise && length(unique(data$variables[[strata]])) > 2) {
-    p_position <- which(colnames(ptb1) == "p")
-    strata_count <- length(unique(data$variables[[strata]]))
-    comparison_columns <- colnames(ptb1)[(p_position - strata_count):(p_position - 1)]
-    pairwise_comparisons <- combn(
-      comparison_columns, 2,
-      simplify = FALSE
-    )
-    pairwise_pvalues_list <- list()
-    for (x in vars) {
-      pairwise_pvalues_list[[x]] <- list()
-      is_continuous <- !(x %in% factorVars) && !is.factor(data$variables[[x]])
-      for (pair in pairwise_comparisons) {
+    unique_strata <- sort(unique(stats::na.omit(data$variables[[strata]])))
+    pairwise_comparisons <- combn(unique_strata, 2, simplify = FALSE)
+    pairwise_names <- sapply(pairwise_comparisons, function(pair) {
+      paste0("p(", pair[1], " vs ", pair[2], ")")
+    })
+    pairwise_pvalues <- stats::setNames(
+      sapply(pairwise_comparisons, function(pair) {
         subset_data <- subset(data, data$variables[[strata]] %in% pair)
-        if (is_continuous) {
-          test_result <- if (x %in% nonnormal) {
-            tryCatch(
-              {
-                test <- survey::svyranktest(as.formula(paste(x, "~", strata)), design = subset_data)
-                list(p_value = test$p.value, test_used = "svyranktest")
-              },
-              error = function(e) {
-                list(p_value = NA, test_used = NA)
-              }
+        subset_data$variables[[strata]] <- droplevels(subset_data$variables[[strata]])
+        tryCatch(
+          {
+            table_result <- svyCreateTableOne2(
+              data = subset_data, strata = strata, vars = vars, factorVars = factorVars, includeNA = includeNA, test = test,
+              showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, smd = smd, nonnormal = nonnormal,
+              catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, Labels = Labels, labeldata = labeldata, minMax = minMax, showpm = showpm,
+              addOverall = addOverall, pairwise = F
             )
-          } else {
-            tryCatch(
-              {
-                test <- survey::svyttest(as.formula(paste(x, "~", strata)), design = subset_data)
-                list(p_value = test$p.value, test_used = "svyttest")
-              },
-              error = function(e) {
-                list(p_value = NA, test_used = NA)
-              }
+            p_values <- table_result[, "p"]
+            test_used <- table_result[, "test"]
+            list(
+              p_value = p_values,
+              test_used = test_used
+            )
+          },
+          error = function(e) {
+            list(
+              p_value = stats::setNames(rep(NA, length(vars)), vars),
+              test_used = stats::setNames(rep(NA, length(vars)), vars)
             )
           }
-        } else {
-          test_result <- tryCatch(
-            {
-              test <- survey::svychisq(as.formula(paste("~", x, "+", strata)), design = subset_data, method = "RaoScott")
-              list(p_value = test$p.value, test_used = "svychisq")
-            },
-            error = function(e) {
-              list(p_value = NA, test_used = NA)
-            }
-          )
-        }
-        pairwise_pvalues_list[[x]][[paste(pair, collapse = "_")]] <- test_result
-      }
-    }
+        )
+      }, simplify = FALSE),
+      nm = pairwise_names
+    )
     for (i in seq_along(pairwise_comparisons)) {
-      col_name <- paste0("p(", pairwise_comparisons[[i]][1], " vs ", pairwise_comparisons[[i]][2], ")")
-      test_name <- paste0("test(", pairwise_comparisons[[i]][1], " vs ", pairwise_comparisons[[i]][2], ")")
+      col_name <- paste0("p(", pairwise_comparisons[[i]][1], "vs", pairwise_comparisons[[i]][2], ")")
+      test_name <- paste0("test(", pairwise_comparisons[[i]][1], "vs", pairwise_comparisons[[i]][2], ")")
       ptb1 <- cbind(ptb1, col_name = "", test_name = "")
       colnames(ptb1)[ncol(ptb1) - 1] <- col_name
       colnames(ptb1)[ncol(ptb1)] <- test_name
     }
-    for (x in vars) {
-      cleaned_var_name <- gsub("\\s+|\\(\\%\\)", "", x)
-      first_row <- which(gsub("\\s+|\\(\\%\\)", "", rownames(ptb1)) == cleaned_var_name)[1]
-
-      for (i in seq_along(pairwise_comparisons)) {
-        pair_key <- paste(pairwise_comparisons[[i]], collapse = "_")
-        p_value <- pairwise_pvalues_list[[x]][[pair_key]]$p_value
-        test_used <- pairwise_pvalues_list[[x]][[pair_key]]$test_used
-        col_name <- paste0("p(", pairwise_comparisons[[i]][1], " vs ", pairwise_comparisons[[i]][2], ")")
-        test_name <- paste0("test(", pairwise_comparisons[[i]][1], " vs ", pairwise_comparisons[[i]][2], ")")
-        p_value <- ifelse(p_value < 0.001, "<0.001", as.character(round(p_value, 2)))
-        ptb1[first_row, col_name] <- p_value
-        ptb1[first_row, test_name] <- test_used
+    for (i in seq_along(pairwise_comparisons)) {
+      col_name <- paste0("p(", pairwise_comparisons[[i]][1], "vs", pairwise_comparisons[[i]][2], ")")
+      test_name <- paste0("test(", pairwise_comparisons[[i]][1], "vs", pairwise_comparisons[[i]][2], ")")
+      pairwise_key <- paste0("p(", pairwise_comparisons[[i]][1], " vs ", pairwise_comparisons[[i]][2], ")")
+      p_value <- pairwise_pvalues[[pairwise_key]]$p_value
+      test_used <- pairwise_pvalues[[pairwise_key]]$test_used
+      p_value_names <- names(p_value)
+      for (x in p_value_names) {
+        if (x != "") {
+          matched_rows <- match(x, rownames(ptb1))
+          if (!is.na(matched_rows)) {
+            ptb1[matched_rows, col_name] <- p_value[x]
+            ptb1[matched_rows, test_name] <- test_used[x]
+          }
+        }
       }
     }
-    cols_to_remove <- grep("^test\\(", colnames(ptb1))
-    ptb1 <- ptb1[, -cols_to_remove]
+    if (!is.null(labeldata) && Labels) {
+      pairwise_p_cols <- grep("^p\\(", colnames(ptb1), value = TRUE)
+      pairwise_test_cols <- grep("^test\\(", colnames(ptb1), value = TRUE)
+
+      strata_labels <- stats::setNames(labeldata[labeldata$variable == strata, val_label], labeldata[labeldata$variable == strata, level])
+      updated_p_colnames <- sapply(pairwise_p_cols, function(col_name) {
+        match <- regmatches(col_name, regexec("^p\\(([^vs]+)vs([^\\)]+)\\)", col_name))
+        if (length(match[[1]]) == 3) {
+          group1 <- match[[1]][2]
+          group2 <- match[[1]][3]
+          label1 <- strata_labels[as.character(group1)]
+          label2 <- strata_labels[as.character(group2)]
+          if (!is.na(label1) && !is.na(label2)) {
+            return(paste0("p(", label1, " vs ", label2, ")"))
+          }
+        }
+        return(col_name)
+      })
+      updated_test_colnames <- sapply(pairwise_test_cols, function(col_name) {
+        match <- regmatches(col_name, regexec("^test\\(([^vs]+)vs([^\\)]+)\\)", col_name))
+        if (length(match[[1]]) == 3) {
+          group1 <- match[[1]][2]
+          group2 <- match[[1]][3]
+          label1 <- strata_labels[as.character(group1)]
+          label2 <- strata_labels[as.character(group2)]
+          if (!is.na(label1) && !is.na(label2)) {
+            return(paste0("test(", label1, " vs ", label2, ")"))
+          }
+        }
+        return(col_name)
+      })
+
+      colnames(ptb1)[colnames(ptb1) %in% pairwise_p_cols] <- updated_p_colnames
+      colnames(ptb1)[colnames(ptb1) %in% pairwise_test_cols] <- updated_test_colnames
+    }
+    if (!pairwise.showtest) {
+      cols_to_remove <- grep("^test\\(", colnames(ptb1))
+      ptb1 <- ptb1[, -cols_to_remove]
+    }
   }
-
-
   sig <- ifelse(ptb1[, "p"] == "<0.001", "0", ptb1[, "p"])
   sig <- as.numeric(as.vector(sig))
   sig <- ifelse(sig <= 0.05, "**", "")
@@ -233,6 +256,7 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
 #' @param showpm Logical, show normal distributed continuous variables as Mean ± SD. Default: T
 #' @param addOverall (optional, only used if strata are supplied) Adds an overall column to the table. Smd and p-value calculations are performed using only the stratifed clolumns. Default: F
 #' @param pairwise (optional, only used if strata are supplied) When there are three or more strata, it displays the p-values for pairwise comparisons. Default: F
+#' @param pairwise.showtest (optional, only used if strata are supplied) When using pairwise comparison, it displays the test used to calculate p-values for pairwise comparisons. Default: F
 #' @return A matrix object containing what you see is also invisibly returned. This can be assinged a name and exported via write.csv.
 #' @details DETAILS
 #' @examples
@@ -258,7 +282,7 @@ svyCreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, te
 svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, factorVars = NULL, includeNA = F, test = T,
                                 showAllLevels = T, printToggle = F, quote = F, smd = F, Labels = F, nonnormal = NULL,
                                 catDigits = 1, contDigits = 2, pDigits = 3, labeldata = NULL, psub = T, minMax = F, showpm = T,
-                                addOverall = F, pairwise = F) {
+                                addOverall = F, pairwise = F, pairwise.showtest = F) {
   . <- level <- variable <- val_label <- V1 <- V2 <- NULL
 
   # if (Labels & !is.null(labeldata)){
@@ -310,7 +334,7 @@ svyCreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, facto
       strata = strata, vars = vars, data = data, factorVars = factorVars, includeNA = includeNA, test = test, smd = smd,
       showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, Labels = Labels, nonnormal = nonnormal,
       catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, labeldata = labeldata, minMax = minMax, showpm = showpm,
-      addOverall = addOverall, pairwise = pairwise
+      addOverall = addOverall, pairwise = pairwise, pairwise.showtest = pairwise.showtest
     )
 
     cap.tb1 <- paste("Stratified by ", strata, "- weighted data", sep = "")
